@@ -34,7 +34,7 @@
 #' The model can be created using the `fit()` function using the
 #'  following _engines_:
 #' \itemize{
-#' \item \pkg{R}:   `"glmnet"`  (the default)
+#' \item \pkg{R}:   `"glmnet"`  (the default), `"nnet"`
 #' \item \pkg{Stan}:  `"stan"`
 #' \item \pkg{keras}: `"keras"`
 #' }
@@ -49,6 +49,10 @@
 #'
 #' \Sexpr[results=rd]{parsnip:::show_fit(parsnip:::multinom_reg(), "glmnet")}
 #'
+#' \pkg{nnet}
+#'
+#' \Sexpr[results=rd]{parsnip:::show_fit(parsnip:::multinom_reg(), "nnet")}
+#'
 #' \pkg{spark}
 #'
 #' \Sexpr[results=rd]{parsnip:::show_fit(parsnip:::multinom_reg(), "spark")}
@@ -197,6 +201,13 @@ organize_multnet_prob <- function(x, object) {
   as_tibble(x)
 }
 
+organize_nnet_prob <- function(x, object) {
+  format_classprobs(x)
+}
+
+
+
+
 # ------------------------------------------------------------------------------
 # glmnet call stack for multinomial regression using `predict` when object has
 # classes "_multnet" and "model_fit" (for class predictions):
