@@ -51,7 +51,7 @@
 #' \Sexpr[results=rd]{parsnip:::show_fit(parsnip:::svm_poly(mode = "regression"), "kernlab")}
 #'
 #' @importFrom purrr map_lgl
-#' @seealso [varying()], [fit()]
+#' @seealso [[fit()]
 #' @examples
 #' svm_poly(mode = "classification", degree = 1.2)
 #' # Parameters can be represented by a placeholder:
@@ -106,11 +106,16 @@ print.svm_poly <- function(x, ...) {
 #' @export
 update.svm_poly <-
   function(object,
+           parameters = NULL,
            cost = NULL, degree = NULL, scale_factor = NULL, margin = NULL,
            fresh = FALSE,
            ...) {
     update_dot_check(...)
 
+    if (!is.null(parameters)) {
+      parameters <- check_final_param(parameters)
+    }
+
     args <- list(
       cost   = enquo(cost),
       degree  = enquo(degree),
@@ -118,6 +123,8 @@ update.svm_poly <-
       margin  = enquo(margin)
     )
 
+    args <- update_main_parameters(args, parameters)
+
     if (fresh) {
       object$args <- args
     } else {
