@@ -6,10 +6,10 @@ library(rlang)
 # ------------------------------------------------------------------------------
 
 context("random forest execution with ranger")
+source("helper-objects.R")
 
 # ------------------------------------------------------------------------------
 
-data("lending_club")
 lending_club <- head(lending_club, 200)
 num_pred <- c("funded_amnt", "annual_inc", "num_il_tl")
 
@@ -19,10 +19,6 @@ lc_ranger <- rand_forest(mode = "classification") %>% set_engine("ranger", seed
 bad_ranger_cls <- rand_forest(mode = "classification") %>% set_engine("ranger", replace = "bad")
 bad_rf_cls <- rand_forest(mode = "classification") %>% set_engine("ranger", sampsize = -10)
 
-ctrl <- control_parsnip(verbosity = 1, catch = FALSE)
-caught_ctrl <- control_parsnip(verbosity = 1, catch = TRUE)
-quiet_ctrl <- control_parsnip(verbosity = 0, catch = TRUE)
-
 # ------------------------------------------------------------------------------
 
 test_that('ranger classification execution', {
@@ -178,10 +174,6 @@ car_basic <- rand_forest(mode = "regression") %>% set_engine("ranger")
 bad_ranger_reg <- rand_forest(mode = "regression") %>% set_engine("ranger", replace = "bad")
 bad_rf_reg <- rand_forest(mode = "regression") %>% set_engine("ranger", sampsize = -10)
 
-ctrl <- list(verbosity = 1, catch = FALSE)
-caught_ctrl <- list(verbosity = 1, catch = TRUE)
-quiet_ctrl <- list(verbosity = 0, catch = TRUE)
-
 # ------------------------------------------------------------------------------
 
 test_that('ranger regression execution', {
