@@ -6,13 +6,12 @@ library(tibble)
 
 # ------------------------------------------------------------------------------
 
+source("helper-objects.R")
+
 basic_form <- Surv(time, status) ~ age
 complete_form <- Surv(time) ~ age
 
 surv_basic <- surv_reg() %>% set_engine("flexsurv")
-ctrl <- control_parsnip(verbosity = 1, catch = FALSE)
-caught_ctrl <- control_parsnip(verbosity = 1, catch = TRUE)
-quiet_ctrl <- control_parsnip(verbosity = 0, catch = TRUE)
 
 # ------------------------------------------------------------------------------
 
